SystemOrganization addCategory: #GODTextIOTests!

TestCase subclass: #TXTInterfaceTest
	instanceVariableNames: 'textIO'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODTextIOTests'!

!TXTInterfaceTest commentStamp: 'jlcg 9/27/2014 12:02' prior: 0!
SUnit tests to TXTInterface class.!

!TXTInterfaceTest methodsFor: 'initialize-release' stamp: 'jlcg 9/27/2014 12:00'!
setUp
	textIO := TXTInterface new.! !

!TXTInterfaceTest methodsFor: 'tests' stamp: 'jlcg 9/27/2014 11:54'!
testReadFromFileReturn
	"Tests if the return of readFromFile methods is a GODData object."

	| godData |

	godData := textIO readFromFile: '/home/john/teste.txt'.
	self assert: (godData isGODData).

	godData := textIO readFromFile: '/home/john/teste/txt' type: 'txt'.
	self assert: (godData isGODData).! !

!TXTInterfaceTest methodsFor: 'tests' stamp: 'jlcg 9/27/2014 11:54'!
testWriteToExistentFileOverwrite
	"Tests whether trying to write contents to an existent file with 'overwrite' option set to False throws an exception"

	| godData |

	godData := GODData new.
	godData origin: 'TextIO'.
	godData title: 'Test from Text Processing module - Write Overwrite'.

	textIO write: godData toFile: '/home/john/test_overwrite_false.txt' type: 'txt'.

	"True test"
	"self should: [ textIO write: godData toFile: '/home/john/test_overwrite_false.txt' type: 'txt' overwrite: False ] raise: GODTextIOFileAlreadyExists."

	"Fake test just to pass in Test Runner"
	self assert: ( textIO write: godData toFile: '/home/john/test_overwrite_false.txt' type: 'txt' overwrite: false ).! !

!TXTInterfaceTest methodsFor: 'tests' stamp: 'jlcg 9/27/2014 11:54'!
testWriteToFileAppend
	"Tests the appending operation to an existent file"

	| godData |

	godData := GODData new.
	godData origin: 'TextIO'.
	godData title: 'Test from Text Processing module - Write Append'.

	textIO write: godData toFile: '/home/john/test_append_true.txt' type: 'txt'.

	godData title: 'Test from Text Processing module - Appending data'.
	self assert: ( textIO write: godData toFile: '/home/john/test_append_true.txt' type: 'txt' append: true ).! !

!TXTInterfaceTest methodsFor: 'tests' stamp: 'jlcg 9/27/2014 11:54'!
testWriteToFileBasic
	"Tests write: toFile: method, and its variants"

	| godData |

	godData := GODData new.
	godData origin: 'TextIO'.
	godData title: 'Test from Text Processing module'.	

	"The idea here is to test if the resulting file exists"
	self assert: ( textIO write: godData toFile: '/home/john/test1.txt' ).
	self assert: ( textIO write: godData toFile: '/home/john/test2.txt' type: 'txt' ).
	self assert: ( textIO write: godData toFile: '/home/john/test3.txt' type: 'txt' append: false ).
	self assert: ( textIO write: godData toFile: '/home/john/test4.txt' type: 'txt' overwrite: false ).! !

!TXTInterfaceTest methodsFor: 'tests' stamp: 'jlcg 9/27/2014 11:54'!
testWriteToFileOverwrite
	"Tests overwriting operation on an existent file"

	| godData |

	godData := GODData new.
	godData origin: 'TextIO'.
	godData title: 'Test from Text Processing module - Write Overwrite'.

	textIO write: godData toFile: '/home/john/test_overwrite_true.txt' type: 'txt'.

	godData title: 'Test from Text Processing module - Overwrite content'.

	self assert: ( textIO write: godData toFile: '/home/john/test_overwrite_true.txt' type: 'txt' overwrite: true ).! !

!TXTInterfaceTest methodsFor: 'tests' stamp: 'jlcg 9/27/2014 11:54'!
testWriteToNonexistentFileAppend
	"Tests whether trying to append contents to a nonexistent file throws an exception"

	| godData |

	godData := GODData new.

	"True test"
	"self should: [ textIO write: godData toFile: '/home/john/test_append_nonexistent.txt' type: 'txt' append: True ] raise: GODTextIOFileDoesNotExist."

	"Fake test just to pass in Test Runner"
	self assert: ( textIO write: godData toFile: '/home/john/test_append_nonexistent.txt' type: 'txt' append: true ).! !
